==> RSTouchscreenNG-1.4.17.zip: RSTouchscreenNG/projects/pages/src/lib/maintainer.component.ts <==
/* (C) 2016-2024 Hot-World GmbH & Co. KG <rlittwin@repetier.com>
 All Rights Reserved

 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY
 DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

 It is allowed to use this code to create or use in products connecting to
 Repetier-Server or to use it for own plugins/modules with Repetier-Server.
 This includes free and commercial products.
 Usage for other products is strictly forbidden.
 */

import {Component} from "@angular/core";
import {ServerAction, RepetierState, ServerState} from "binding";
import {Observable, SubscriptionLike} from "rxjs";
import {RSModal, RSStringKeyboard} from "front-ui";
import {Store} from "@ngrx/store";

@Component({
  // eslint-disable-next-line @angular-eslint/component-selector
  selector: "rs-maintainer",
  template: `
    <rs-page>
      <rs-side>
        <rs-sideicon title="<?php _('Menu') ?>" icon="rs-menu" link="/"></rs-sideicon>
      </rs-side>
      <rs-side>
        <rs-sideicon *rsIfConnected="true" icon="rs rs-params" title="<?php _('Status') ?>" link="/params"></rs-sideicon>
        <rs-empty-sideicon *rsIfConnected="false"></rs-empty-sideicon>
      </rs-side>
      <rs-side>
        <rs-sideicon *rsIfConnected="true" icon="rs rs-printer-commands" title="<?php _('Console') ?>" link="/console"></rs-sideicon>
        <rs-empty-sideicon *rsIfConnected="false"></rs-empty-sideicon>
      </rs-side>
      <main *ngIf="(server$|async).features['hasMaintainer']">
        <rs-headline><i class="fa fa-magic"></i> <?php _('Maintainer') ?></rs-headline>
        <div *rsIfConnected="true" class="content-h1" rsDrag>
          <div>
            <div class="margin-leftright" *ngIf="(server$|async).features['maintainer']">
              <rs-button class="secondary outline full" (hit)="serverAction.disableMaintainer()">
                <rs-icon icon="fa fa-lock"></rs-icon>
                <h3 class="text" style="padding:8px"><?php _('Disable Maintainer Permissions') ?></h3></rs-button>
            </div>
            <div class="margin-leftright" *ngIf="!(server$|async).features['maintainer']">
              <rs-button class="secondary outline full" (hit)="enableMaintainer()">
                <rs-icon icon="fa fa-lock"></rs-icon>
                <h3 class="text" style="padding:8px"><?php _('Enable Maintainer Permissions') ?></h3></rs-button>
              <div *ngIf="wrongPassword" class="alert error margin">
                <?php _('Wrong password!') ?>
              </div>
              <div  class="alert info margin">
                <?php _('Some functions are only available for the authorized maintainer. Here the maintainer can activate the disabled function.') ?>
              </div>
            </div>

          </div>
        </div>
      </main>
    </rs-page>
  `
})
export class MaintainerComponent {
  server$: Observable<ServerState>;
  wrongPassword = false
  constructor(public serverAction: ServerAction,
              public modal: RSModal,
     public stringKbd: RSStringKeyboard,
              private store: Store<RepetierState>) {
    this.server$ = store.select("server");
  }

  async enableMaintainer() {
   this.wrongPassword = false
    const pw = await this.stringKbd.getString("", "<?php _('Maintainer Mode Password') ?>", {password: true})
    if(!await this.serverAction.enableMaintainer(pw)) {
      this.wrongPassword = true
    }
  }
}

==> RSTouchscreenNG-1.4.18.zip: RSTouchscreenNG/projects/pages/src/lib/maintainer.component.ts <==
/* (C) 2016-2024 Hot-World GmbH & Co. KG <rlittwin@repetier.com>
 All Rights Reserved

 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY
 DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

 It is allowed to use this code to create or use in products connecting to
 Repetier-Server or to use it for own plugins/modules with Repetier-Server.
 This includes free and commercial products.
 Usage for other products is strictly forbidden.
 */

import {Component, OnDestroy} from "@angular/core";
import {ServerAction, RepetierState, ServerState, PrintersState, PrinterState} from "binding";
import {Observable, SubscriptionLike} from "rxjs";
import {RSModal, RSStringKeyboard} from "front-ui";
import {Store} from "@ngrx/store";

@Component({
  // eslint-disable-next-line @angular-eslint/component-selector
  selector: "rs-maintainer",
  template: `
    <rs-page>
      <rs-side>
        <rs-sideicon title="<?php _('Menu') ?>" icon="rs-menu" link="/"></rs-sideicon>
      </rs-side>
      <rs-side>
        <rs-sideicon *rsIfConnected="true" icon="rs rs-params" title="<?php _('Status') ?>" link="/params"></rs-sideicon>
        <rs-empty-sideicon *rsIfConnected="false"></rs-empty-sideicon>
      </rs-side>
      <rs-side>
        <rs-sideicon *ngIf="printer?.online===1 && (server$|async).features['show-console'] && (server$|async).features['touch-console']" icon="rs rs-printer-commands" title="<?php _('Console') ?>" link="/console"></rs-sideicon>
        <rs-empty-sideicon *rsIfConnected="false"></rs-empty-sideicon>
      </rs-side>
      <main *ngIf="(server$|async).features['hasMaintainer']">
        <rs-headline><i class="fa fa-magic"></i> <?php _('Maintainer') ?></rs-headline>
        <div *rsIfConnected="true" class="content-h1" rsDrag>
          <div>
            <div class="margin-leftright" *ngIf="(server$|async).features['maintainer']">
              <rs-button class="secondary outline full" (hit)="serverAction.disableMaintainer()">
                <rs-icon icon="fa fa-lock"></rs-icon>
                <h3 class="text" style="padding:8px"><?php _('Disable Maintainer Permissions') ?></h3></rs-button>
            </div>
            <div class="margin-leftright" *ngIf="!(server$|async).features['maintainer']">
              <rs-button class="secondary outline full" (hit)="enableMaintainer()">
                <rs-icon icon="fa fa-lock"></rs-icon>
                <h3 class="text" style="padding:8px"><?php _('Enable Maintainer Permissions') ?></h3></rs-button>
              <div *ngIf="wrongPassword" class="alert error margin">
                <?php _('Wrong password!') ?>
              </div>
              <div  class="alert info margin">
                <?php _('Some functions are only available for the authorized maintainer. Here the maintainer can activate the disabled function.') ?>
              </div>
            </div>

          </div>
        </div>
      </main>
    </rs-page>
  `
})
export class MaintainerComponent implements OnDestroy {
  server$: Observable<ServerState>;
  printers$: Observable<PrintersState>;
  wrongPassword = false
  private printersSubscription: SubscriptionLike;
  printer: PrinterState;
  constructor(public serverAction: ServerAction,
              public modal: RSModal,
              public stringKbd: RSStringKeyboard,
              private store: Store<RepetierState>) {
    this.server$ = store.select("server");
    this.printers$ = store.select('printers');
    this.printersSubscription = this.printers$.subscribe((p: PrintersState) => {
      if (p.active) {
        this.printer = p.printers[p.active];
      }
    });
  }

  ngOnDestroy() {
    this.printersSubscription.unsubscribe();
  }

  async enableMaintainer() {
    this.wrongPassword = false
    const pw = await this.stringKbd.getString("", "<?php _('Maintainer Mode Password') ?>", {password: true})
    if(!await this.serverAction.enableMaintainer(pw)) {
      this.wrongPassword = true
    }
  }
}
